@@ -12,6 +12,7 @@ import time
 from reV.config.hybrids_config import HybridsConfig
 from reV.pipeline.status import Status
 from reV.hybrids.hybrids import Hybridization, SOLAR_PREFIX, WIND_PREFIX
+from reV.utilities import ModuleName
 from reV import __version__
 
 from rex.utilities.hpc import SLURM
@@ -24,9 +25,8 @@ logger = logging.getLogger(__name__)
 
 @click.group()
 @click.version_option(version=__version__)
-@click.option('--name', '-n', default='reV-hybrids', type=STR,
-              show_default=True,
-              help='Job name. Default is "reV-hybrids".')
+@click.option('--name', '-n', default=os.path.basename(os.getcwd()),
+              type=STR, show_default=True, help='reV Hybrids job name.')
 @click.option('-v', '--verbose', is_flag=True,
               help='Flag to turn on debug logging. Default is not verbose.')
 @click.pass_context
@@ -54,29 +54,25 @@ def valid_config_keys():
 @click.pass_context
 def from_config(ctx, config_file, verbose):
     """Run reV hybridization from a config file."""
-    name = ctx.obj['NAME']
-
     # Instantiate the config object
     config = HybridsConfig(config_file)
 
-    # take name from config if not default
-    if config.name.lower() != 'rev':
-        name = config.name
-        ctx.obj['NAME'] = name
+    # take name from config
+    name = ctx.obj['NAME'] = config.name
 
     # Enforce verbosity if logging level is specified in the config
     if config.log_level == logging.DEBUG:
         verbose = True
 
     # initialize loggers
-    init_mult(name, config.logdir, modules=[__name__, 'reV', 'rex'],
+    init_mult(name, config.log_directory, modules=[__name__, 'reV', 'rex'],
               verbose=verbose)
 
     # Initial log statements
     logger.info('Running reV hybridization from config '
                 'file: "{}"'.format(config_file))
     logger.info('Target output directory: "{}"'.format(config.dirout))
-    logger.info('Target logging directory: "{}"'.format(config.logdir))
+    logger.info('Target logging directory: "{}"'.format(config.log_directory))
     logger.debug('The full configuration input is as follows:\n{}'
                  .format(pprint.pformat(config, indent=4)))
 
@@ -86,11 +82,14 @@ def from_config(ctx, config_file, verbose):
 
         ctx.obj['NAME'] = name
         if config.execution_control.option == 'local':
-            status = Status.retrieve_job_status(config.dirout, 'hybrids', name)
+            status = Status.retrieve_job_status(config.dirout,
+                                                module=ModuleName.HYBRIDS,
+                                                job_name=name)
 
             if status != 'successful':
                 Status.add_job(
-                    config.dirout, 'hybrids', name, replace=True,
+                    config.dirout, module=ModuleName.HYBRIDS,
+                    job_name=name, replace=True,
                     job_attrs={'hardware': 'local',
                                'fout': '{}.h5'.format(name),
                                'dirout': config.dirout})
@@ -105,7 +104,7 @@ def from_config(ctx, config_file, verbose):
                            ratio_bounds=config.ratio_bounds,
                            ratio=config.ratio,
                            out_dir=config.dirout,
-                           log_dir=config.logdir,
+                           log_dir=config.log_directory,
                            verbose=verbose)
 
         elif config.execution_control.option in ('eagle', 'slurm'):
@@ -118,7 +117,7 @@ def from_config(ctx, config_file, verbose):
             ctx.obj['RATIO_BOUNDS'] = config.ratio_bounds
             ctx.obj['RATIO'] = config.ratio
             ctx.obj['OUT_DIR'] = config.dirout
-            ctx.obj['LOG_DIR'] = config.logdir
+            ctx.obj['LOG_DIR'] = config.log_directory
             ctx.obj['VERBOSE'] = verbose
 
             ctx.invoke(slurm,
@@ -305,7 +304,7 @@ def direct(ctx, solar_fpath, wind_fpath, allow_solar_only, allow_wind_only,
                   'job_status': 'successful',
                   'runtime': runtime,
                   'finput': [solar_fpath, wind_fpath]}
-        Status.make_job_file(out_dir, 'hybrids', name, status)
+        Status.make_job_file(out_dir, ModuleName.HYBRIDS, name, status)
 
 
 def get_node_cmd(ctx):
@@ -402,10 +401,11 @@ def slurm(ctx, alloc, memory, walltime, feature, conda_env, module,
         slurm_manager = SLURM()
         ctx.obj['SLURM_MANAGER'] = slurm_manager
 
-    status = Status.retrieve_job_status(out_dir, 'hybrids', name,
-                                        hardware='eagle',
+    status = Status.retrieve_job_status(out_dir, module=ModuleName.HYBRIDS,
+                                        job_name=name, hardware='eagle',
                                         subprocess_manager=slurm_manager)
 
+    msg = 'Hybrids CLI failed to submit jobs!'
     if status == 'successful':
         msg = ('Job "{}" is successful in status json found in "{}", '
                'not re-running.'
@@ -424,10 +424,10 @@ def slurm(ctx, alloc, memory, walltime, feature, conda_env, module,
             msg = ('Kicked off reV hybridization job "{}" '
                    '(SLURM jobid #{}).'
                    .format(name, out))
-            Status.add_job(
-                out_dir, 'hybrids', name, replace=True,
-                job_attrs={'job_id': out, 'hardware': 'eagle',
-                           'fout': '{}.h5'.format(name), 'dirout': out_dir})
+        Status.add_job(
+            out_dir, module=ModuleName.HYBRIDS, job_name=name, replace=True,
+            job_attrs={'job_id': out, 'hardware': 'eagle',
+                       'fout': '{}.h5'.format(name), 'dirout': out_dir})
 
     click.echo(msg)
     logger.info(msg)
