@@ -18,6 +18,7 @@ from reV.supply_curve.competitive_wind_farms import CompetitiveWindFarms
 from reV.utilities.exceptions import SupplyCurveInputError, SupplyCurveError
 from reV.utilities import log_versions
 
+from rex import Resource
 from rex.utilities import parse_table, SpawnProcessPool
 
 logger = logging.getLogger(__name__)
@@ -60,13 +61,15 @@ class SupplyCurve:
         Total LCOE of each supply curve point considering the LCOE friction
         scalar from the aggregation step (mean_lcoe_friction + lcot) ($/MWh).
     """
+
     def __init__(self, sc_points, trans_table, sc_features=None):
         """
         Parameters
         ----------
         sc_points : str | pandas.DataFrame
-            Path to .csv or .json or DataFrame containing supply curve
-            point summary
+            Path to .csv or .json or DataFrame containing supply curve point
+            summary. Can also now be a filepath to a bespoke h5 where the
+            "meta" dataset has the same format as the sc aggregation output.
         trans_table : str | pandas.DataFrame | list
             Path to .csv or .json or DataFrame containing supply curve
             transmission mapping, can also be a list of transmission tables
@@ -111,7 +114,9 @@ class SupplyCurve:
         Parameters
         ----------
         sc_points : str | pandas.DataFrame
-            Path to .csv or .json or DataFrame containing supply curve
+            Path to .csv or .json or DataFrame containing supply curve point
+            summary. Can also now be a filepath to a bespoke h5 where the
+            "meta" dataset has the same format as the sc aggregation output.
         sc_features : str | pandas.DataFrame
             Path to .csv or .json or DataFrame containing additional supply
             curve features, e.g. transmission multipliers, regions
@@ -122,7 +127,14 @@ class SupplyCurve:
             DataFrame of supply curve point summary with additional features
             added if supplied
         """
-        sc_points = parse_table(sc_points)
+        if isinstance(sc_points, str) and sc_points.endswith('.h5'):
+            with Resource(sc_points) as res:
+                sc_points = res.meta
+                sc_points.index.name = 'sc_gid'
+                sc_points = sc_points.reset_index()
+        else:
+            sc_points = parse_table(sc_points)
+
         logger.debug('Supply curve points table imported with columns: {}'
                      .format(sc_points.columns.values.tolist()))
 
@@ -202,9 +214,12 @@ class SupplyCurve:
         # trans_line_gids -> gids of transmission lines connected to the given
         # transmission feature (only used for Substations),
         # legacy name: trans_gids
-        trans_table = \
-            trans_table.rename(columns={'trans_line_gid': 'trans_gid',
-                                        'trans_gids': 'trans_line_gids'})
+        # also xformer_cost_p_mw -> xformer_cost_per_mw (not sure why there
+        # would be a *_p_mw but here we are...)
+        rename_map = {'trans_line_gid': 'trans_gid',
+                      'trans_gids': 'trans_line_gids',
+                      'xformer_cost_p_mw': 'xformer_cost_per_mw'}
+        trans_table = trans_table.rename(columns=rename_map)
 
         if 'dist_mi' in trans_table and 'dist_km' not in trans_table:
             trans_table = trans_table.rename(columns={'dist_mi': 'dist_km'})
@@ -235,20 +250,35 @@ class SupplyCurve:
             Updated table mapping supply curve points to transmission features
             based on maximum capacity
         """
-        mask = trans_sc_table['capacity'] <= trans_sc_table['max_cap']
-        over_max = trans_sc_table.loc[~mask].copy()
-        trans_sc_table = trans_sc_table.loc[mask]
-        if over_max.size:
+
+        nx = trans_sc_table['capacity'] / trans_sc_table['max_cap']
+        nx = np.ceil(nx).astype(int)
+        trans_sc_table['n_parallel_trans'] = nx
+
+        if (nx > 1).any():
+            mask = nx > 1
+            tie_line_cost = (trans_sc_table.loc[mask, 'tie_line_cost']
+                             * nx[mask])
+
+            xformer_cost = (trans_sc_table.loc[mask, 'xformer_cost_per_mw']
+                            * trans_sc_table.loc[mask, 'max_cap'] * nx[mask])
+
+            conn_cost = (xformer_cost
+                         + trans_sc_table.loc[mask, 'sub_upgrade_cost']
+                         + trans_sc_table.loc[mask, 'new_sub_cost'])
+
+            trans_cap_cost = tie_line_cost + conn_cost
+
+            trans_sc_table.loc[mask, 'tie_line_cost'] = tie_line_cost
+            trans_sc_table.loc[mask, 'xformer_cost'] = xformer_cost
+            trans_sc_table.loc[mask, 'connection_cost'] = conn_cost
+            trans_sc_table.loc[mask, 'trans_cap_cost'] = trans_cap_cost
+
             msg = ("{} SC points have a capacity that exceeds the maximum "
-                   "transmission feature capacity and will be mapped to "
-                   "features with the max capacity"
-                   .format(len(over_max['sc_gid'].unique())))
-            logger.warning(msg)
-            warn(msg)
-            over_max = over_max.sort_values('max_cap')
-            over_max = over_max.drop_duplicates(subset=['sc_gid', 'trans_gid'],
-                                                keep='last')
-            trans_sc_table = trans_sc_table.append(over_max)
+                   "transmission feature capacity and will be connected with "
+                   "multiple parallel transmission features."
+                   .format((nx > 1).sum()))
+            logger.info(msg)
 
         return trans_sc_table
 
@@ -849,35 +879,38 @@ class SupplyCurve:
         conn_lists = {k: deepcopy(init_list) for k in columns}
 
         trans_sc_gids = trans_table['sc_gid'].values.astype(int)
-        trans_gids = trans_table['trans_gid'].values
-        trans_cap = trans_table['avail_cap'].values
-        capacities = trans_table['capacity'].values
-        categories = trans_table['category'].values
-        dists = trans_table['dist_km'].values
-        trans_cap_costs = trans_table['trans_cap_cost_per_mw'].values
-        lcots = trans_table['lcot'].values
-        total_lcoes = trans_table['total_lcoe'].values
+
+        # syntax is final_key: source_key (source from trans_table)
+        all_cols = {k: k for k in columns}
+        essentials = {'trans_gid': 'trans_gid',
+                      'trans_capacity': 'avail_cap',
+                      'trans_type': 'category',
+                      'dist_km': 'dist_km',
+                      'trans_cap_cost_per_mw': 'trans_cap_cost_per_mw',
+                      'lcot': 'lcot',
+                      'total_lcoe': 'total_lcoe',
+                      }
+        all_cols.update(essentials)
+
+        arrays = {final_key: trans_table[source_key].values
+                  for final_key, source_key in all_cols.items()}
+
+        sc_capacities = trans_table['capacity'].values
 
         connected = 0
         progress = 0
         for i in range(len(trans_table)):
             sc_gid = trans_sc_gids[i]
             if self._mask[sc_gid]:
-                trans_gid = trans_gids[i]
-                connect = trans_features.connect(trans_gid, capacities[i])
+                connect = trans_features.connect(arrays['trans_gid'][i],
+                                                 sc_capacities[i])
                 if connect:
                     connected += 1
                     logger.debug('Connecting sc gid {}'.format(sc_gid))
                     self._mask[sc_gid] = False
 
-                    conn_lists['trans_gid'][sc_gid] = trans_gid
-                    conn_lists['trans_capacity'][sc_gid] = trans_cap[i]
-                    conn_lists['trans_type'][sc_gid] = categories[i]
-                    conn_lists['trans_cap_cost_per_mw'][sc_gid] = \
-                        trans_cap_costs[i]
-                    conn_lists['dist_km'][sc_gid] = dists[i]
-                    conn_lists['lcot'][sc_gid] = lcots[i]
-                    conn_lists['total_lcoe'][sc_gid] = total_lcoes[i]
+                    for col_name, data_arr in arrays.items():
+                        conn_lists[col_name][sc_gid] = data_arr[i]
 
                     if total_lcoe_fric is not None:
                         conn_lists['total_lcoe_friction'][sc_gid] = \
@@ -992,6 +1025,7 @@ class SupplyCurve:
             Updated sc_points table with transmission connections, LCOT
             and LCOE+LCOT based on full supply curve connections
         """
+        logger.info('Starting full competitive supply curve sort.')
         self._check_substation_conns(self._trans_table)
         self.compute_total_lcoe(fcr, transmission_costs=transmission_costs,
                                 avail_cap_frac=avail_cap_frac,
@@ -1044,7 +1078,7 @@ class SupplyCurve:
                     avail_cap_frac=1, max_workers=None,
                     consider_friction=True, sort_on='total_lcoe',
                     columns=('trans_gid', 'trans_type', 'lcot', 'total_lcoe',
-                             'trans_cap_cost_per_mw'),
+                             'dist_km', 'trans_cap_cost_per_mw'),
                     wind_dirs=None, n_dirs=2, downwind=False,
                     offshore_compete=False):
         """
@@ -1101,6 +1135,7 @@ class SupplyCurve:
             Updated sc_points table with transmission connections, LCOT
             and LCOE+LCOT based on simple supply curve connections
         """
+        logger.info('Starting simple supply curve sort (no capacity limits).')
         self.compute_total_lcoe(fcr, transmission_costs=transmission_costs,
                                 avail_cap_frac=avail_cap_frac,
                                 connectable=False,
@@ -1151,8 +1186,9 @@ class SupplyCurve:
         Parameters
         ----------
         sc_points : str | pandas.DataFrame
-            Path to .csv or .json or DataFrame containing supplcy curve
-            point summary
+            Path to .csv or .json or DataFrame containing supply curve point
+            summary. Can also now be a filepath to a bespoke h5 where the
+            "meta" dataset has the same format as the sc aggregation output.
         trans_table : str | pandas.DataFrame
             Path to .csv or .json or DataFrame containing supply curve
             transmission mapping
@@ -1230,8 +1266,9 @@ class SupplyCurve:
         Parameters
         ----------
         sc_points : str | pandas.DataFrame
-            Path to .csv or .json or DataFrame containing supplcy curve
-            point summary
+            Path to .csv or .json or DataFrame containing supply curve point
+            summary. Can also now be a filepath to a bespoke h5 where the
+            "meta" dataset has the same format as the sc aggregation output.
         trans_table : str | pandas.DataFrame
             Path to .csv or .json or DataFrame containing supply curve
             transmission mapping
